// InstallDriver.cpp : Defines the entry point for the console application.
//

#include "stdafx.h"
#include "libwdi.h"
#include <Windows.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <commctrl.h>
#include <commdlg.h>

#define safe_strdup _strdup
struct wdi_device_info* wdi_dev_list = NULL;

typedef struct
{
	struct wdi_device_info* wdi;
	
	char description[MAX_PATH];
	char manufacturer[MAX_PATH];
	
	char inf_name[MAX_PATH];
	char inf_dir [MAX_PATH];
	char inf_path[MAX_PATH];
	
	BOOL user_allocated_wdi;
	BOOL modified; // unused
	
	VS_FIXEDFILEINFO driver_info;
} device_context_t;

int prepare_driver(device_context_t *device)
{
	struct wdi_options_prepare_driver options;
	int ret;
	
	memset(&options,0,sizeof(options));
	options.driver_type = WDI_LIBUSB0;
	options.vendor_name = device->manufacturer;
	
	if (device->wdi->desc)
		free(device->wdi->desc);
	device->wdi->desc = safe_strdup(device->description);
	
	ret = wdi_prepare_driver(device->wdi, device->inf_dir, device->inf_name, &options);
	
	return ret;
}

int install_driver(HWND hWnd, device_context_t *device)
{
	struct wdi_options_install_driver options;
	int ret;
	
	if (device == NULL)
		return WDI_ERROR_NO_DEVICE;
	memset(&options,0,sizeof(options));
	options.hWnd = hWnd;

	ret = wdi_install_driver(device->wdi, device->inf_dir, device->inf_name, &options);

	return ret;
}

typedef HWND (WINAPI *PROCGETCONSOLEWINDOW)();
PROCGETCONSOLEWINDOW GetConsoleWindow;

void usage()
{
	printf("InstallDriver [manufacturer] [description] [INFPath]\n");
	printf("Example: InstallDriver Micosoft terminaldevice test.inf\n");
}

int main(int argc, char* argv[])
{
	device_context_t device;
	int ret;
	char InfPath[MAX_PATH];
	
	if (argc != 4)
	{
		usage();
		exit(-1);
	}
	
	memset(&device, 0, sizeof(device));
	
	HMODULE hKernel32 = GetModuleHandle("kernel32");
	GetConsoleWindow = (PROCGETCONSOLEWINDOW)GetProcAddress(hKernel32,"GetConsoleWindow");
	HWND cmd=GetConsoleWindow();

	device.user_allocated_wdi = TRUE;
	device.wdi = (struct wdi_device_info*)malloc(sizeof(struct wdi_device_info));
	memset(device.wdi,0,sizeof(struct wdi_device_info));
	
	device.wdi->vid = 0xD1EE;			//޸
	device.wdi->pid = 0x4153;

	device.wdi->is_composite=false;
	strcpy(device.manufacturer, argv[1]);
	strcpy(device.description,  argv[2]);

	memset(device.inf_path, 0, sizeof(device.inf_path));
	memset(device.inf_dir,0,sizeof(device.inf_dir));
	memset(device.inf_name,0,sizeof(device.inf_name));
	
	//ȡinf·                       
	GetCurrentDirectory(MAX_PATH,device.inf_dir);  
	strncpy(device.inf_name,  argv[3], MAX_PATH);
	
	ret = prepare_driver(&device);
	if (ret != WDI_SUCCESS)
	{
		printf("װʧ%d\n", ret);
		exit(-1);
	}

	ret = install_driver(cmd, &device);
	if (ret != WDI_SUCCESS)
	{
		printf("װʧ%d\n", ret);
		exit(-1);
	}
	
	printf("װɹ\n");
	return 0;
}

